@@ -1,7 +1,7 @@
-from __future__ import unicode_literals
-
 from django.apps import AppConfig
+from django.utils.translation import gettext_lazy as _
 
 
 class TokenBlacklistConfig(AppConfig):
     name = 'rest_framework_simplejwt.token_blacklist'
+    verbose_name = _('Token Blacklist')
